function [B0,B1,B2] = plot_act(refs,grid,d)

% PLOT_ACT   Plot the alternative base-level activation formulas.
%   
%   PLOT_ACT(REFS,GRID,D)   produces a plot.
%   [B0 B1 B2] = PLOT_ACT(REFS,GRID,D)  returns three vectors
%     corresponding to the exact formula BASE_ACT, and the approximations 1
%     and 2, respectively.
%
%   REFS and GRID should use the same time scale.
%   When not supplied, D defaults to the global variable DECAY.
%
%   Example:  plot_act([0:3:50],[0.1:0.5:70],0.5)
%
%   See also BASE_ACT, B_APPROX1, B_APPROX2.

%   Original coding by Alexander Petrov, Carnegie Mellon University.
%   $Revision: 1.0 $  $Date: 1999/10/25 15:30 $

%%% GLOBAL VARIABLES
global DECAY

if (nargin == 2)
   d = DECAY ;
end

%%% Preallocate arrays
B0 = zeros(size(grid)) ;
B1 = zeros(size(grid)) ;
B2 = zeros(size(grid)) ;

time_of_creation = refs(1) ;

%%% Main loop
for k = 1:length(grid)
  curr_time = grid(k) ;
  relevant_refs = refs(refs < curr_time) ;
  lags = curr_time - relevant_refs ;
  T = curr_time - time_of_creation ;     % lifetime of the chunk
  t = lags(end) ;                        % time since last reference
  n = length(lags) ;                     % number of references so far
  
  B0(k) = base_act(lags,d) ;
  B1(k) = B_approx1(T,n,d) ;
  B2(k) = B_approx2(t,T,n-1,d) ;
end

%%% Plot if called as command
if (nargout == 0)
  figure ;
  title(['d = ' num2str(d)]) ;
  xlabel('time') ;
  hold on ;
  axis([-Inf Inf -1 +2]) ;
  plot(refs, zeros(size(refs)),'r^') ;
  h0 = plot(grid,B0,'r:') ;
  h1 = plot(grid,B1,'b') ;
%  h2 = plot(grid,B2,'g') ;
%  legend([h0 h1], 'ln(sum(tj^-^d))', 'ln(nT^-^d/(1-d))') ;
end

%%%%% End of PLOT_ACT.M
