function  col_p = is_col_vector(object)

% IS_COL_VECTOR -- True for numeric column vectors, including scalars.
%
%  IS_COL_VECTOR(A) returns 1 if A satisfies ISNUMERIC, has two
%  dimensions only, and SIZE(A,2) is equal to 1.
%
%  Examples:
%    is_col_vector(3.14)      ==> 1
%    is_col_vector([3 1 4])   ==> 0
%    is_col_vector([3 1 4]')  ==> 1
%    is_col_vector({3 1 4})   ==> 0
%
%  See also IS_ROW_VECTOR, ISNUMERIC, ISSTRUCT, ISCELL.

% Original coding by Alex Petrov, Ohio State University
% $Revision: 1.0 $  $Date: 2000/06/13 20:30 $
%
% Part of the utils toolbox version 1.1 for MATLAB version 5 and up.
% http://alexpetrov.com/softw/utils/
% Copyright (c) Alexander Petrov 1999-2006, http://alexpetrov.com
% Please read the LICENSE and NO WARRANTY statement in ../utils_license.m

if (~isnumeric(object))
  col_p = 0 ;
elseif (ndims(object) > 2)
  col_p = 0 ;
else
  col_p = (size(object,2)==1) ;
end

%%  Return COL_P
%%%%%% End of file IS_COL_VECTOR.M
